Kp

Struct Kp 

pub struct Kp<R, V, Root, Value, MutRoot, MutValue, G, S>
where Root: Borrow<R>, MutRoot: BorrowMut<R>, MutValue: BorrowMut<V>, G: Fn(Root) -> Option<Value>, S: Fn(MutRoot) -> Option<MutValue>,
{ pub get: G, pub set: S, /* private fields */ }
AKp (AnyKeyPath) - Hides both Root and Value types Most flexible keypath type for heterogeneous collections Uses dynamic dispatch and type checking at runtime

Mutation: get vs get_mut (setter path)

  • get uses the get closure (getter): Fn(Root) -> Option<Value>
  • get_mut uses the set closure (setter): Fn(MutRoot) -> Option<MutValue>

When mutating through a Kp, the setter path is used—get_mut invokes the set closure, not the get closure. The getter is for read-only access only.

Fields

get: G

Getter closure: used by Kp::get for read-only access.

set: S

Setter closure: used by Kp::get_mut for mutation.

Implementations

Source

impl<'a, R, V> Kp<R, V, &'a R, &'a V, &'a mut R, &'a mut V, for<'b> fn(&'b R) -> Option<&'b V>, for<'b> fn(&'b mut R) -> Option<&'b mut V>>
where 'a: 'static,

pub fn to_dynamic(self) -> KpDynamic<R, V>

Converts this keypath (KpType) to KpDynamic for dynamic dispatch and storage. Requires 'a: 'static so the boxed getter/setter closures can be 'static.

Source

impl<R, V> Kp<R, V, &'static R, &'static V, &'static mut R, &'static mut V, Box<dyn for<'b> Fn(&'b R) -> Option<&'b V> + Send + Sync>, Box<dyn for<'b> Fn(&'b mut R) -> Option<&'b mut V> + Send + Sync>>

pub fn from_closures<G, S>(get: G, set: S) -> Self
where G: for<'b> Fn(&'b R) -> Option<&'b V> + Send + Sync + 'static, S: for<'b> Fn(&'b mut R) -> Option<&'b mut V> + Send + Sync + 'static,

Build a keypath from two closures (e.g. when they capture a variable like an index). Same pattern as Kp::new in lock.rs; use this when the keypath captures variables.

Source

impl<R, V, Root, Value, MutRoot, MutValue, G, S> Kp<R, V, Root, Value, MutRoot, MutValue, G, S>
where Root: Borrow<R>, Value: Borrow<V>, MutRoot: BorrowMut<R>, MutValue: BorrowMut<V>, G: Fn(Root) -> Option<Value>, S: Fn(MutRoot) -> Option<MutValue>,

pub fn new(get: G, set: S) -> Self

pub fn then<SV, SubValue, MutSubValue, G2, S2>( self, next: Kp<V, SV, Value, SubValue, MutValue, MutSubValue, G2, S2>, ) -> Kp<R, SV, Root, SubValue, MutRoot, MutSubValue, impl Fn(Root) -> Option<SubValue>, impl Fn(MutRoot) -> Option<MutSubValue>>
where SubValue: Borrow<SV>, MutSubValue: BorrowMut<SV>, G2: Fn(Value) -> Option<SubValue>, S2: Fn(MutValue) -> Option<MutSubValue>, V: 'static,

Source

impl<R, Root, MutRoot, G, S> Kp<R, R, Root, Root, MutRoot, MutRoot, G, S>
where Root: Borrow<R>, MutRoot: BorrowMut<R>, G: Fn(Root) -> Option<Root>, S: Fn(MutRoot) -> Option<MutRoot>,

pub fn identity_typed() -> Kp<R, R, Root, Root, MutRoot, MutRoot, fn(Root) -> Option<Root>, fn(MutRoot) -> Option<MutRoot>>

pub fn identity<'a>() -> KpType<'a, R, R>