pub type KpOwned<R, V> = Kp<R, V, R, V, R, V, fn(R) -> Option<V>, fn(R) -> Option<V>>;Expand description
Kp will force dev to create get and set while root and value both will be owned
Aliased Type
pub struct KpOwned<R, V> { /* private fields */ }