KpRoot

Type Alias KpRoot 

pub type KpRoot<R> = Kp<R, R, R, R, R, R, fn(R) -> Option<R>, fn(R) -> Option<R>>;
Kp will force dev to create get and set while taking full ownership of the Root while returning Root as value.

Aliased Type

pub struct KpRoot<R> { /* private fields */ }